@@ -1,5 +1,5 @@
-#!/usr/share/ucs-test/runner python3
-## desc: Test the reconnect mechanism of univention-ldapsearch
+#!/usr/share/ucs-test/runner pytest-3 -s
+# ## desc: Test the reconnect mechanism of univention-ldapsearch
 ## tags: [apptest,reconnect]
 ## roles: [domaincontroller_master,domaincontroller_backup,domaincontroller_slave]
 ## packages: [python3-psutil]
@@ -11,10 +11,11 @@
 
 from multiprocessing import Process
 from queue import Empty, Full
-from subprocess import PIPE, Popen
+from subprocess import PIPE, Popen, check_call
 from time import sleep
 
 import psutil
+import pytest
 
 from univention.config_registry import ConfigRegistry, handler_set
 from univention.testing.utils import fail
@@ -22,6 +23,8 @@ from univention.testing.utils import fail
 
 UCR = ConfigRegistry()
 UCR.load()
+base_dn = None
+ucr_retry_count = None
 
 
 def restore_retry_count():
@@ -85,29 +88,33 @@ def perform_univention_ldapsearch(fail_on_success=False):
 def stop_slapd():
     """
     Stops the slapd and waits for it to be stopped.
-    Looks for slapd in processes and waits if found extra 15 seconds.
+    Looks for slapd in processes and waits if found extra 20 seconds.
     """
-    ret_code = Popen(('invoke-rc.d', 'slapd', 'stop')).wait()
-    if ret_code != 0:
-        fail("Expecting the return code to be 0, while it is: %s" % ret_code)
+    check_call(['systemctl', 'stop', 'slapd'])
 
-    # look for process and wait up to 15 seconds for its termination:
+    # look for process and wait up to 20 seconds for its termination:
     for proc in psutil.process_iter():
         try:
             if 'slapd' in proc.name() and proc.ppid() == 1:
-                print("\nThe 'slapd' is still running, waiting...")
+                print("\nThe 'slapd' is still running, waiting ...")
                 try:
-                    proc.wait(15)
+                    proc.wait(20)
                     print("slapd terminated.")
                 except psutil.TimeoutExpired:
-                    fail("\nFailed to wait for slapd to terminate.\n")
+                    print("\nThe 'slapd' is still running, killing ...")
+                    proc.kill()
+                    try:
+                        proc.wait(20)
+                        print("slapd terminated.")
+                    except psutil.TimeoutExpired:
+                        fail("\nFailed to wait for slapd to terminate.\n")
         except psutil.NoSuchProcess:
             pass
 
 
 def start_slapd():
     """Starts the slapd and wait for it to be started."""
-    ret_code = Popen(('invoke-rc.d', 'slapd', 'start')).wait()
+    ret_code = Popen(('systemctl', 'start', 'slapd')).wait()
     if ret_code not in (0, 2):
         fail("Expecting the return code to be 0 or 2, while it is: %s"
              % ret_code)
@@ -115,11 +122,11 @@ def start_slapd():
 
 def start_with_delay(delay):
     """Sleeps the given 'delay' and starts slapd."""
-    Popen('sleep %s; invoke-rc.d slapd start' % delay, shell=True)
+    Popen('sleep %s; systemctl start slapd' % delay, shell=True)
 
 
 def wait_for_slapd_to_be_started():
-    """Looks for slapd process and sleeos few seconds if not found."""
+    """Looks for slapd process and sleeps few seconds if not found."""
     for proc in psutil.process_iter():
         if 'slapd' in proc.name() and proc.ppid() == 1:
             # 'slapd' process found
@@ -135,64 +142,53 @@ def print_test_header(header):
     print('**********************************************************************************')
 
 
-def main():
-    try:
-        set_ucr_retry_count(10)
-        print_test_header("Case 1: Stop and start slapd with 5 secs "
-                          "delay. Perform search. Retry count is 10.")
-        stop_slapd()
-        start_with_delay(5)
-        perform_univention_ldapsearch()
-        wait_for_slapd_to_be_started()
-
-        set_ucr_retry_count(1)
-        print_test_header("Case 2: Stop and start slapd with 5 secs "
-                          "delay. Perform search. Retry count is 1.")
-        print("Expecting that search case won't work, as retry count is 1 and start delay is 5.")
-        stop_slapd()
-        start_with_delay(5)
-        perform_univention_ldapsearch(True)  # fail on success
-        wait_for_slapd_to_be_started()
-
-        set_ucr_retry_count(11)
-        print_test_header("Case 3: Stop and start slapd with 7 secs "
-                          "delay. Perform search. Retry count is 11.")
-        stop_slapd()
-        start_with_delay(7)
-        perform_univention_ldapsearch()
-        wait_for_slapd_to_be_started()
-
-        set_ucr_retry_count(0)
-        print_test_header("Case 4: No server restart. "
-                          "Perform search. Retry count is 0.")
-        perform_univention_ldapsearch()
-
-        print_test_header("Case 5: Stop and start slapd with 5 secs "
-                          "delay. Perform search. Retry count is 0.")
-        print("Expecting that search case won't work, as retry count is 0 "
-              "and start delay is 5.")
-        stop_slapd()
-        start_with_delay(5)
-        perform_univention_ldapsearch(True)  # fail on success
-    finally:
-        restore_retry_count()
-        # try to restore slapd systemd status
-        Popen(('systemctl', 'daemon-reload')).wait()
-        Popen(('service', 'slapd', 'stop')).wait()
-        Popen(('service', 'slapd', 'start')).wait()
-        sleep(5)
-
-
-if __name__ == '__main__':
-    """
-    Tests that reconnect of univention-ldapsearch works with slapd restart.
-    """
+@pytest.fixture(scope='session', autouse=True)
+def setup():
+    global base_dn, ucr_retry_count
     ucr_retry_count = UCR.get('ldap/client/retry/count')
     print(("Saving initial 'ldap/client/retry/count' UCR setting =",
-          ucr_retry_count))
+           ucr_retry_count))
     base_dn = UCR.get('ldap/base')
-
-    main()
-
-    # Wait for some seconds otherwise the following test case will fail Bug #45828
+    yield
+    restore_retry_count()
+    # try to restore slapd systemd status
+    Popen(('systemctl', 'daemon-reload')).wait()
+    Popen(('service', 'slapd', 'stop')).wait()
+    Popen(('service', 'slapd', 'start')).wait()
     sleep(5)
+
+
+descriptios = [
+    "Case 1: Stop and start slapd with 5 secs delay. Perform search. Retry count is 10.",
+    """Case 2: Stop and start slapd with 5 secs delay. Perform search. Retry count is 1.
+Expecting that search case won't work, as retry count is 1 and start delay is 5.""",
+    "Case 3: Stop and start slapd with 7 secs delay. Perform search. Retry count is 11.",
+    "Case 4: No server restart. Perform search. Retry count is 0.",
+    """Case 5: Stop and start slapd with 5 secs delay. Perform search. Retry count is 0.
+Expecting that search case won't work, as retry count is 0 and start delay is 5.""",
+]
+
+
+@pytest.mark.parametrize('description_index,operations', [
+    (0, [("ucr_retry_count", 10), "stop", ("start", 5), ("search", False), "wait_for_slap_to_be_restarted"]),
+    (1, [("ucr_retry_count", 1), "stop", ("start", 5), ("search", True), "wait_for_slap_to_be_restarted"]),
+    (2, [("ucr_retry_count", 11), "stop", ("start", 7), ("search", False), "wait_for_slap_to_be_restarted"]),
+    (3, [("ucr_retry_count", 0), ("search", False)]),
+    (4, [("ucr_retry_count", 0), "stop", ("start", 5), ("search", True)]),
+])
+def test_reconnect_univention_ldapsearch(description_index, operations):
+    print_test_header(descriptios[description_index])
+    for op in operations:
+        if isinstance(op, tuple):
+            if op[0] == "ucr_retry_count":
+                set_ucr_retry_count(op[1])
+            elif op[0] == "start":
+                start_with_delay(op[1])
+            elif op[0] == "search":
+                perform_univention_ldapsearch(op[1])
+        elif op == "stop":
+            stop_slapd()
+        elif op == "wait_for_slap_to_be_restarted":
+            wait_for_slapd_to_be_started()
+        else:
+            fail("Invalid operation: %s" % op)
