@@ -21,7 +21,7 @@ TRANSLOG_CMD = '/usr/share/univention-directory-notifier/univention-translog'
 ])
 def test_translog_check_fail(cmd, capfd):
     with pytest.raises(subprocess.CalledProcessError) as exc_info:
-        subprocess.check_call([TRANSLOG_CMD] + cmd.split())
+        subprocess.check_call([TRANSLOG_CMD, *cmd.split()])
 
     assert exc_info.value.returncode
 
@@ -34,7 +34,7 @@ def test_translog_check_fail(cmd, capfd):
     "ldap 1",
 ])
 def test_translog_check(cmd, capfd):
-    subprocess.check_call([TRANSLOG_CMD] + cmd.split())
+    subprocess.check_call([TRANSLOG_CMD, *cmd.split()])
     stdout, stderr = capfd.readouterr()
     assert stdout > ""
     assert stderr == ""
@@ -47,7 +47,7 @@ def test_translog_check(cmd, capfd):
     pytest.param("-n -l import -m 1 -M 1"),
 ])
 def test_translog_check_silent(cmd, capfd):
-    subprocess.check_call([TRANSLOG_CMD] + cmd.split())
+    subprocess.check_call([TRANSLOG_CMD, *cmd.split()])
     stdout, stderr = capfd.readouterr()
     assert stdout == ""
     assert stderr == ""
