@@ -9,33 +9,11 @@
 import subprocess
 import time
 
-import pytest
-
 import univention.testing.strings as uts
-import univention.testing.ucr as ucr_test
-import univention.testing.udm as udm_test
 
 from essential.mail import random_email
 
 
-@pytest.fixture
-def udm():
-    with udm_test.UCSTestUDM() as udm:
-        yield udm
-
-
-@pytest.fixture
-def ucr():
-    with ucr_test.UCSTestConfigRegistry() as ucr:
-        yield ucr
-
-
-@pytest.fixture
-def fqdn():
-    with ucr_test.UCSTestConfigRegistry() as ucr:
-        return '%(hostname)s.%(domainname)s' % ucr
-
-
 def test_populate_file_and_resync(udm, ucr, fqdn):
     for i in range(5):
         remote_username = uts.random_string()
