@@ -22,7 +22,7 @@ import univention.testing.strings as uts
 from univention.testing import utils
 from univention.testing.strings import random_string, random_username
 from univention.testing.ucr import UCSTestConfigRegistry
-from univention.testing.udm import UCSTestUDM, UCSTestUDM_CreateUDMObjectFailed
+from univention.testing.udm import UCSTestUDM
 # ruff: noqa: A004
 from univention.udm import (
     UDM, ApiVersionMustNotChange, ApiVersionNotSupported, ConnectionError, NoApiVersionSet, WrongObjectType,
@@ -64,15 +64,14 @@ class TestUdmUsersBasic(TestCase):
             cls.mail_domain = cls.ucr_test['mail/hosteddomains'].split()[0]
         except (AttributeError, IndexError):
             cls.mail_domain = cls.ucr_test['domainname']
-            try:
-                cls.udm_test.create_object(
-                    'mail/domain',
-                    position='cn=domain,cn=mail,{}'.format(cls.ucr_test['ldap/base']),
-                    name=cls.mail_domain,
-                    wait_for_replication=True,
-                )
-            except UCSTestUDM_CreateUDMObjectFailed as exc:
-                print(f'Creating mail domain {cls.mail_domain!r} failed: {exc}')
+
+        cls.udm_test.create_object(
+            'mail/domain',
+            position='cn=domain,cn=mail,{}'.format(cls.ucr_test['ldap/base']),
+            name=cls.mail_domain,
+            wait_for_replication=True,
+            ignore_exists=True,
+        )
 
     @classmethod
     def tearDownClass(cls):
