@@ -95,7 +95,7 @@ class Test_DNSResolve:
         assert answer == zoneName, f'IPv4: resolved name "{answer}" != created ldap-object "{zoneName}"'
 
         # IPv6
-        ipv6 = '2011:06f8:13dc:0002:19b7:d592:09dd:1041'.split(':')  # create uts.random_ipV6()?
+        ipv6 = ['2011', '06f8', '13dc', '0002', '19b7', 'd592', '09dd', '1041']  # create uts.random_ipV6()?
         subnet = ipv6[:7]
         reverse_zone_properties.update({
             'subnet': ':'.join(subnet),
@@ -287,7 +287,7 @@ class Test_DNSResolve:
         assert answer == [ptr_record], f'resolved name "{answer}" != created ldap-object "{[ptr_record]}"'
 
         # IPv6
-        ipv6 = '2011:06f8:13dc:0002:19b7:d592:09dd:1041'.split(':')  # create uts.random_ipV6()?
+        ipv6 = ['2011', '06f8', '13dc', '0002', '19b7', 'd592', '09dd', '1041']  # create uts.random_ipV6()?
         subnet = ipv6[:7]
         reverse_zone_properties.update({
             'subnet': ':'.join(subnet),
@@ -326,7 +326,7 @@ class Test_DNSResolve:
         udm.create_object('dns/forward_zone', position=pos, **forward_zone_properties)
         utils.wait_for_replication_and_postrun()
         answers = resolve_dns_entry(zone, 'TXT')
-        # FIXME PMH-2017-01-14: returned TXT data is enclosed in "
+        # FIXME(@pmhahn): 2017-01-14: returned TXT data is enclosed in "
         answer = [rdata.to_text().strip('"') for rdata in answers]
         assert answer == [txt], f'resolved name "{answer}" != created ldap-object "{[txt]}"'
 
