@@ -51,7 +51,7 @@ def test_app_ports_conflicts_exclusive(appcenter, app_version):
         # check if installation fails
         # if exclusive port is already used
         app.install()
-        app.verify(joined=False)
+        app.verify()
         with pytest.raises(UCSTest_DockerApp_InstallationFailed):
             exclusive.install()
         with pytest.raises(UCSTest_DockerApp_InstallationFailed):
@@ -59,7 +59,7 @@ def test_app_ports_conflicts_exclusive(appcenter, app_version):
 
         # another app should be fine
         dummy.install()
-        dummy.verify(joined=False)
+        dummy.verify()
     finally:
         app.uninstall()
         app.remove()
