@@ -16,7 +16,7 @@ import univention.testing.udm as udm_test
 def test_write_event():
     with udm_test.UCSTestUDM() as udm, ucr_test.UCSTestConfigRegistry() as ucr, univention.admindiary.backend.get_client(version=1) as client:
         d = (datetime.datetime.now() - datetime.timedelta(seconds=5)).isoformat()
-        dn, username = udm.create_user()
+        _dn, username = udm.create_user()
         expected = {
             'id': 33,
             'date': datetime.datetime.now().strftime('%y-%m-%d %H:%M:%S'),
